#' Extract Species ID from Parsed XML
#'
#' This function extracts a species ID from the parsed XML document using
#' an XPath expression.
#'
#' @param parsed A parsed XML document.
#'
#' @return A character vector containing the extracted species ID.
#' @importFrom XML xpathSApply xmlValue
#' @export
get_abid <- function(parsed) {
  abid <- XML::xpathSApply(
    parsed, "//script[contains(text(), 'get_args')]",
    XML::xmlValue
  ) |>
    gsub(pattern = "^.*species_id=([0-9]*).*$", replacement = "\\1", x = _)
  return(abid)
}
