#' Extract Taxonomic Name and Species ID from Parsed XML
#'
#' This function extracts a taxonomic name and optionally an associated species
#' ID from the parsed XML document.
#'
#' @param parsed A parsed XML document.
#' @param getabid Logical; if TRUE, returns both the taxonomic name and species ID.
#'
#' @return A character vector of taxonomic names, or a tibble with taxonomic
#' names and species IDs.
#' @importFrom XML xpathSApply xmlValue
#' @importFrom dplyr tibble
#' @export
get_curtaxname <- function(parsed, getabid = FALSE) {
  taxname <- XML::xpathSApply(
    parsed,
    "//p[b[contains(text(), 'Status of name')]]/span[contains(text(), 'regarded as a synonym of ')]/a/text()",
    XML::xmlValue
  )
  if (is.null(taxname)) {
    if (getabid) {
      return(dplyr::tibble())
    }
    return(NA)
  }
  if (!getabid) {
    return(taxname)
  }
  abid <- XML::xpathSApply(
    parsed,
    "//p[b[contains(text(), 'Status of name')]]/span[contains(text(), 'regarded as a synonym of ')]/a/@href"
  ) |>
    as.character() |>
    gsub(pattern = "^.*=", replacement = "", x = _)
  return(dplyr::tibble(taxname = taxname, abid = abid))
}
