#' Get Synonym Data Frame
#'
#' Extracts synonym information from parsed XML data.
#'
#' @param parsed Parsed HTML/XML content.
#' @param getabid Logical, if TRUE, also returns species id (abid).
#' @return A tibble containing synonym names or an empty tibble if no synonyms
#'         found.
#' @importFrom XML xpathSApply xmlValue
#' @importFrom dplyr tibble
#' @export
get_synonymdf <- function(parsed, getabid = FALSE) {
  taxname <- XML::xpathSApply(parsed, "//p[a and strong[contains(text(), 'Synonym')]]//a/text()", XML::xmlValue)
  if (is.null(taxname)) {
    if (getabid) {
      return(dplyr::tibble())
    }
    return(NA)
  }
  if (!getabid) {
    return(taxname)
  }
  abid <- XML::xpathSApply(parsed, "//p[a and strong[contains(text(), 'Synonym')]]//a/@href") |>
    as.character() |>
    gsub(pattern = "^.*=", replacement = "", x = _)

  return(dplyr::tibble(taxname = taxname, abid = abid))
}
