#' Get Image Information
#'
#' Extracts image information from parsed taxonomic HTML content.
#'
#' @param parsed Parsed HTML/XML content.
#' @return A tibble with image metadata including title, description, and links.
#' @importFrom XML xpathSApply
#' @importFrom dplyr tibble mutate rename_all
#' @importFrom stringr str_split
#' @importFrom readr parse_number
#' @export
get_taximginfo <- function(parsed) {
  noimg <- XML::xpathSApply(parsed, "//a[@class='jq_lightbox']/@onclick") |> is.null()
  if (noimg) {
    return(dplyr::tibble())
  }
  imginfo <- XML::xpathSApply(parsed, "//a[@class='jq_lightbox']/@onclick") |>
    as.character() |>
    stringr::str_split("<br />", simplify = TRUE) |>
    dplyr::as_tibble() |>
    dplyr::rename_all(~ c("title", "description", "copyright", "link")) |>
    dplyr::mutate(title = gsub("this\\.title='", "", title)) |>
    dplyr::mutate(imgid = readr::parse_number(gsub(
      "^.*\\(Image Ref\\. (\\d{1,})\\)",
      "\\1", title
    ))) |>
    dplyr::mutate(link = gsub(
      "^.*(http\\S*)\\\\' target.*$", "\\1",
      .data$link
    ))
  return(imginfo)
}
