#' Get Taxonomic Levels
#'
#' Extracts classification levels from parsed HTML/XML content.
#'
#' @param parsed Parsed HTML/XML content.
#' @return A tibble with taxonomic classification levels.
#' @importFrom XML xpathSApply xmlValue
#' @importFrom dplyr as_tibble mutate_all rename_all
#' @export
get_taxlevel <- function(parsed) {
  taxlevel <- XML::xpathSApply(
    parsed,
    "//p[b[contains(text(), 'Classification')]]/a/text()", XML::xmlValue
  ) |>
    rbind() |>
    as.data.frame() |>
    dplyr::as_tibble() |>
    dplyr::mutate_all(~ as.character(.)) |>
    dplyr::rename_all(~ tolower(XML::xpathSApply(
      parsed, "//p[b[contains(text(), 'Classification')]]/i/b",
      XML::xmlValue
    )))
  return(taxlevel)
}
