#' Check if a Taxon Name Represents a Genus
#'
#' This function determines whether a given taxon name represents only a genus.
#' It optionally removes certain unwanted substrings from the name and normalizes
#' it for comparison.
#'
#' @param taxname Character. The taxon name to be checked.
#' @param addsp Logical. If `TRUE`, species-related substrings are removed
#' before checking for genus. Default is `FALSE`.
#'
#' @export
#' @return Logical. `TRUE` if the taxon name represents a genus, `FALSE` otherwise.
isgenus <- function(taxname, addsp = FALSE) {
  taxname <- taxname |>
    iconv(to = "ASCII//TRANSLIT") |>
    gsub(pattern = "A<", replacement = "e", x = _, fixed = TRUE) |>
    gsub(pattern = "Cfr. ", replacement = "", x = _, ignore.case = TRUE) |>
    gsub(pattern = "cf ", replacement = "", x = _, ignore.case = TRUE) |>
    gsub(pattern = "cf.", replacement = "", x = _, ignore.case = TRUE) |>
    gsub(pattern = "colony", replacement = "", x = _, ignore.case = TRUE) |>
    gsub(pattern = "colonies", replacement = "", x = _, ignore.case = TRUE) |>
    gsub(pattern = "cells", replacement = "", x = _, ignore.case = TRUE) |>
    gsub(pattern = "\\s{2,}", replacement = " ", x = _, ignore.case = TRUE) |>
    trimws(which = "both")
  genusonly.pat <- "\\ssp{1,2}[1-9\\.]{0,1}(\\s|$)"
  return(grepl(genusonly.pat, taxname))
}
